package ink.wgink.mongo.login.startup;

import ink.wgink.interfaces.user.mongo.IMongoLoginUserService;
import ink.wgink.properties.ServerProperties;
import ink.wgink.service.user.service.IUserService;
import ink.wgink.service.user.util.UserUtil;
import ink.wgink.util.thread.CachedThreadPoolUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

/**
 * @ClassName: MongoLoginStartUp
 * @Description: mongo启动
 * @Author: wanggeng
 * @Date: 2022/5/19 16:25
 * @Version: 1.0
 */
@Component
public class MongoLoginStartUp implements ApplicationRunner {

    private static final Logger LOG = LoggerFactory.getLogger(MongoLoginStartUp.class);
    @Autowired
    private ServerProperties serverProperties;
    @Autowired
    private IMongoLoginUserService mongoLoginUserService;
    @Autowired
    private IUserService userService;

    @Override
    public void run(ApplicationArguments args) throws Exception {
        if (serverProperties.getMasterNode()) {
            LOG.debug("master-node: {}" + serverProperties.getMasterNode());
            CachedThreadPoolUtil.execute(() -> {
                // 初始化所有账号内容
                System.out.println("**************************");
                System.out.println("** LoginUser Init Start **");
                System.out.println("**************************");
                long startTime = System.currentTimeMillis();
                Map<String, Object> params = new HashMap<>(0);
                userService.listPO(params).forEach(userPO -> {
                    mongoLoginUserService.update(UserUtil.createLoginUser(userPO));
                });
                long endTime = System.currentTimeMillis();
                System.out.println("**************************");
                System.out.println("**  LoginUser Init End  **");
                System.out.println("**************************");
                LOG.debug("LoginUser init used time: {}ms", (endTime - startTime) / 1000L);
            });
        }
    }

}
